[![CircleCI](https://dl.circleci.com/status-badge/img/gh/portant-shop/mailing/tree/master.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/portant-shop/mailing/tree/master)

# mailing
a django app for sending emails in portant
